@@ -42,6 +42,7 @@ title=*SH_bn* section=1 repnl=\040
 	~$ *SH_bn* -s	#>> output sample. use -S to see full grammer
 	~$ *SH_bn* -s | *SH_bn*	#>> conv
 	~$ *SH_bn* src.ccl src.ccl		#>> cat src.ccl src.ccl|*SH_bn*
+	~$ *SH_bn* src.ccl | tee src.tcl	#>> general use
 	@()@
 
 	@(code)--@
@@ -49,10 +50,10 @@ title=*SH_bn* section=1 repnl=\040
 	//cmt2                  | #cmt2
 	#cmt3                   | #cmt3
 	puts [[1 +2]]           | puts [expr 1+ 2]
-	$b=1+2; $b(1, 2 3)="$a" | set b [expr 1+2 ]; set b(1,23) "$a"
-	if($a++)                | if {[incr a]} {..}
+	b=1+2; b(1, 2 3)="$a"   | set b [expr 1+2 ]; set b(1,23) "$a"
+	if(a++)                 | if {[incr a]} {..}
 	{..};                   | 
-	for($i=0;$i<9;$i++){..} | for {set $i 0} {$i<9} {incr i} {..}
+	for(i=0;$i<9;i++){..}   | for {set i 0} {$i<9} {incr i} {..}
 	@()
 @_opt
 	@(list_o)
@@ -72,12 +73,12 @@ title=*SH_bn* section=1 repnl=\040
 	Topical performance such as learning cost, stability, history,
 	portability will come next to C language and POSIX-Shell. --
 	The problem is that the code is a command, so typing is difficult.
-	CCL was created to improve this.
+	CCL improves it.
 @conforming_to	posix-shell
 @copyright
 	Copyright (C) 2022 Momi-g --
 	License GPLv3+ <https://gnu.org/licenses/gpl.html>
-@_ver 2022-03-28 v1.0.1 (2022-03-26 v1.0.0)
+@_ver 2022-03-28 v1.1.0 (2022-03-26 v1.0.0)
 @_see https://www.tcl-lang.org --
 	https://en.wikipedia.org/wiki/Tcl
 #SH_docE
@@ -94,9 +95,10 @@ HowTo (*SH_bn* - ccl(alt_tcl/tk) to tcl transpiler)
 opt: -sS(ample), -hHV(hHelp,version)
 ---
 eg) ~$ *SH_bn* -s	#>> output TL_DR text
-    ~$ *SH_bn* -S |less	#>> disp ccl full-grammer
+    ~$ *SH_bn* -S | less	#>> disp ccl full-grammer
     ~$ cat src.ccl | *SH_bn* 	#>> exec transpile
     ~$ *SH_bn* src.ccl  	#>> cat ag1 ag2..|ccl2tcl if ag exists
+    ~$ *SH_bn* src.ccl | tee src.tcl	#>> general use
 EEE
 exit 0
 }
@@ -142,31 +144,30 @@ readlinkp()(
 	printf '%s/%s' "$PWD" "${b##*/}_"
 )
 # readlinkp: end
-exdir=`readlinkp -f "$0"`
+exdir=`readlinkp "$0"`
 exdir=$(dirname "$exdir")
 
 f_sample(){
 cat<<'EEE'
-//sample.ccl
+#sample.ccl
 /* this code shows allmost all
 the ccl extension syntax */
-#normal_cmt
 
 puts [[1 +2]]; puts $a(1 ,2); puts 'hw{}gw'
-$b=1+2; $b(1, 2 3) = $a		// assign=, iter++ needs header '$'
-$b='1+2'; $b = $a	//lv = rv, if rv top isnt {['" ,add [expr...]  
-b=1+2	//ignore if ccl syntax isnt
-$b++; ${b}++;$b(1, $a)++
-if($a++)
-{..}; while(a++){..}	
-for($i=0;$i<10;$i++){..}
-loop(10){ $a = [[$a +1]] }	//loop() is changed to for(), _i is fixed
-fn myf(a, $10 z){...}	//fn name() is changed to proc()
+b=1+2; b(1, 2 3) = "$a"	//assign: lv must varname except '$'
+b='1+2'; {b} = "$a"	// rv==calc if top isnt {['" 
+$b=1+2	//ignore if ccl syntax isnt
+b++ ;{b}++ ;b(1,  $a)++
+if(a++)		//if,elif,elseif,else
+{..}; while(a="b"){..}	
+for(i=0;$i<10;i++){..}
+loop(10){ a = [[$a +1]] }	//loop() is changed to for(), _i is fixed
+fn myf(a, $10 z){...}	//fn name() is changed to proc(). '$' is/isnt
 
 //pragma_rawb
-[[1+2]], ccl2tcl skips 'pragma_raw(\n)' b-e lines 
-//pragma_rawb
+[[1+2]], ccl2tcl skips 'pragma_raw(sp*)(\n)' b-e lines 
 #pragma_rawe
+ccl_printf "123"	//see -S opt + rep_word 
 
 // ~$ ./ccl2tcl -s | ./ccl2tcl
 // ~$ ./ccl2tcl -S | less
@@ -183,9 +184,9 @@ cat<<'EEE'
 #	calc: [[...]]	>> [expr ...]
 #	blk : {..[[nest_work]]..}, '..sh-qu}..' >> { [expr ] }, {..sh-qu\}..} 
 #	val : $a(1  , a$b)	>> $a(1,a$b)
-#	assign: $a(1, 2 3) = 1; $a='z'	>> set a(1,23) [expr 1 ]; set a {z}
-#	iter  : ${i}++, $abc(0 3)--	>> incr {i}, incr abc(03) -1
-#	flow: if/while(1){..}, for($i=0;$i<1;abc $i++){..}, loop(10){..}
+#	assign: a(1, 2 3) = 1; a='z'	>> set a(1,23) [expr 1 ]; set a {z}
+#	iter  : {i}++, 'i'++, "i"--, abc(0 3)--	>> incr {i}, incr abc(03) -1
+#	flow: if/while(1){..}, for(i=0;$i<1;abc i++){..}, loop(10){..}
 #		>> if {1} {...}, for {set i 0} {$i<1} {abc incr i}
 #		>> (loop '_i' is fix) for {set _i 10} {$_i>0} {incr _i -1} {..} 
 #	def : fn/proc myf($10, b,$c){...}	>> proc myf {10 b c} {...}
@@ -195,24 +196,30 @@ cat<<'EEE'
 # - avoid non-genaral varname: OK: $a(1) $a::b2(2), AVOID: $_)(%&(1) 
 # - single quote '' works the same as shell '' and cant hold sq itself
 # - ccl2tcl doesnt parse sq_blk '..' inner strings
-# - assign 'lv=rv' works if: lv top is '$', rv top isnt {['" >> calc  
+# - assign 'lv=rv' works if rv top isnt {['" >> calc  
 
 #--main_rules
 BOF <- !!.
 code <- node / .	# {}() may hit to '.', for support ccl syntax
 node <- CMT		# corerule 
 	/ BLANK / SEP
-	/ CB_BLK / DQ_BLK / SQ_BLK
 	/ ext_stx		# $a=1, fn(){} etc
+	/ CB_BLK / DQ_BLK / SQ_BLK
 	/ CMDR	# replace [..]
+	/ rep_word		#'printf' >> 'format' etc
 	/ CSEQ	# Char Sequences
 EOF <- !.
 #--main_rules_end
 
+	#--replace name,word,token etc
+rep_word <- 'ccl_printf' ![a-zA-Z0-9_]		{_1 = 'format'}
+	#	/ 'printf' ![a-zA-Z0-9_]		{_1 = 'format'}
+	#	/ 'pf'	![a-zA-Z0-9_]		{_1 = 'format'}
+
 	#--cmn
 BLANK <- e'([ \t\n]|\r\n)+'
 	/ EOF
-NL <- e'(\r\n|\n)'
+NL <- e'(\r\n|\n)' / EOF
 SP <- e'[ \t]+'
 SEP <- ';'
 CHAR <- e'(\\.|\\\r\n|.)'
@@ -223,7 +230,7 @@ CMT <- rawcode/ lcmt / mcmt / ocmt		# // /**/ == ;#, ;if 0 { ... }
 rawcode <- NL? e'[^\n]*pragma_rawb' SP* NL
 	(! e'[^\n]*pragma_rawe[ \t]*(\r\n|\n)' .)*
 	e'[^\n]*pragma_rawe' SP* NL
-	{_2=_4 ';#rawcode_b'; _6 = _4 ';#rawcode_e' }
+	{_2=_4 ';#rawcode_b'; _6 = ';#rawcode_e' }
 
 lcmt <- '//' e'[^\n]*\n' { _1 = ';#' }
 	# yx(  [^x]*[y]  |  [x]*[^xy] )*  x+y >> /[*]([^*]*[/]|[*]*[^*/])*[*]+/
@@ -247,9 +254,10 @@ SQ_BLK <- "'" sqCHAR* "'" 	{ _0 = ' {' _2 '} ' }
 CSEQ <- (CMDR/VAR/!(SEP/BLANK/e'[][{}()]')CHAR)+
 
 	#--ignore_array_blank:	$a(1 2 , ) >> $a(12,)
-VAR	<-	 e'\$[{](\\}|[^}])*[}]'		# ${...} >> dont parse in ${var} nameblk
-		/	e'[$][a-zA-Z0-9_:]+' _IDX	
-		/	e'[$][a-zA-Z0-9_:]+'
+VAR <- '$' VNAME
+VNAME <-	e'[{](\\}|[^}])*[}]'		# ${...} >> dont parse in ${var} nameblk
+		/	e'[a-zA-Z0-9_:]+' _IDX	
+		/	e'[a-zA-Z0-9_:]+'
 _IDX <- '(' _IDXags* ')'	# (1,   3 4) >> (1,34)
 	_IDXags <- BLANK? _IDXag BLANK? ','?  { _1=''; _3='' }
 	_IDXag <- ( CMDR / VAR / !(SEP/BLANK/e'[],)]')CHAR )+
@@ -260,15 +268,15 @@ ext_stx <- ass	# a = 10
 	/ fdef	# fn fname(a,b=10){...}
 
 	#---ass
-ass <- '$' LNAME BLANK? !OP '=' BLANK? RVAL {_0='set ' _2 ' ' _7 }
-	/ '$' LNAME '++'	{_0='incr ' _2 }
-	/ '$' LNAME '--'	{_0='incr ' _2 ' -1' }
-LNAME <- e'[{](\\}|[^}])*[}]'		# {name}
-		/ e'[a-zA-Z0-9_:]+' _IDX	# name(1, 3)
-		/ e'[a-zA-Z0-9_:]+'			# name
+ass <- LNAME BLANK? !OP '=' BLANK? RVAL {_0='set ' _1 ' ' _6 }
+	/ LNAME '++'	{_0='incr ' _1 }
+	/ LNAME '--'	{_0='incr ' _1 ' -1' }
+LNAME <- VNAME
+		/ SQ_BLK
+		/ DQ_BLK
 OP <- '==' / '<=' / '>=' / '!='		# '=' >> assign, '==' >> compare
 RVAL <- CMDR / CB_BLK / DQ_BLK / SQ_BLK
-	/ (!(NL/SEP) code)+ { _0 = '[expr ' _0 ' ]' }
+	/ (!(NL/SEP/CMT) code)+ { _0 = '[expr ' _0 ' ]' }
 
 	#---flow:  if/for/while/loop (1==1){...} >> if { 1==1 } { ... }
 flow <- flow_if	/ flow_for 
@@ -345,33 +353,41 @@ test_1(){
 	buf=`echo '$a(1  , a$b)' |*SH_bn*_main`
 	_eq '$a(1,a$b)' "$buf"	"msg:arr"
 
-	buf=`echo '$a(1, 2 3) = [[1 +2]]' |*SH_bn*_main`
-	_eq 'set a(1,23) [expr 1 +2 ]' "$buf"	"msg:arr"
+	buf=`echo 'a(1, 2 3) = [[1 +2]]' |*SH_bn*_main`
+	_eq 'set a(1,23) [expr 1 +2 ]' "$buf"	"msg:arrass"
 
-	buf=`echo '${a}++ $abc(0 3)--' |*SH_bn*_main`
-	_eq 'incr {a} incr abc(03) -1' "$buf"	"msg:iter"
-
-	buf=`echo 'if(1){..}' |*SH_bn*_main`
-	_eq 'if {1}  {..} ' "$buf"	"msg:if"
+	buf=`echo 'if($a == 1){..}' |*SH_bn*_main`
+	_eq 'if {$a == 1}  {..} ' "$buf"	"msg:if"
 
 	buf=`echo 'fn myf($1, b,$c){..}' |*SH_bn*_main`
 	_eq 'proc myf { 1 b c  }  {..} ' "$buf"	"msg:fn"
 #add
+	buf=`echo "'a'++ {a}++ abc(0 3)--" |*SH_bn*_main`
+	_eq 'incr  {a}  incr {a} incr abc(03) -1' "$buf"	"msg:iter"
 
-	buf=`echo '$a = 12' |*SH_bn*_main`
+	buf=`echo '"a"++' |*SH_bn*_main`
+	_eq 'incr  "a" ' "$buf"	"msg:dqiter"
+
+	buf=`echo 'a = 12' |*SH_bn*_main`
 	_eq 'set a [expr 12 ]' "$buf"	"msg: expr ass"
 
-	buf=`echo '$a = {12}' |*SH_bn*_main`
+	buf=`echo '"a" = 12' |*SH_bn*_main`
+	_eq 'set  "a"  [expr 12 ]' "$buf"	"msg: expr ass2"
+
+	buf=`echo 'a = "12"' |*SH_bn*_main`
+	_eq 'set a  "12" ' "$buf"	"msg: direct ass"
+
+	buf=`echo 'a = {12}' |*SH_bn*_main`
 	_eq 'set a  {12} ' "$buf"	"msg: cb ass"
 
-	buf=`echo '$a = [[12]]' |*SH_bn*_main`
+	buf=`echo 'a = [[12]]' |*SH_bn*_main`
 	_eq 'set a [expr 12 ]' "$buf"	"msg: [] ass"
 
-	buf=`echo '$a = "12[[1]]"' |*SH_bn*_main`
+	buf=`echo 'a = "12[[1]]"' |*SH_bn*_main`
 	_eq 'set a  "12[expr 1 ]" ' "$buf"	"msg: dq ass"
 
-	buf=`echo '$'"a = '12[[1]]'" |*SH_bn*_main`
-	_eq "set a  {12[[1]]} " "$buf"	"msg: aq ass"
+	buf=`echo "a = '12[[1]]'" |*SH_bn*_main`
+	_eq "set a  {12[[1]]} " "$buf"	"msg: sq ass"
 
 #	_res
 }
@@ -383,6 +399,13 @@ cat << EEE >/dev/null
 /*
  change log
  --
+2022-03-28 Momi-g	<dmy@dmy.dmy>
+
+	* *SH_bn* (ccl.ped): change assign $a = 1 >> a=1. v1.1.0
+	: allow lv==VNAME, DQ, SQ >> beta test
+	: del 'pragma_rawe' trailing blank line
+	: add rep_word, ccl_printf >> format etc
+	
 2022-03-28 Momi-g	<dmy@dmy.dmy>
 
 	* *SH_bn* (ccl.ped): add $a = ![{['"]123 >> expr. v1.0.1
